Welcome to palaestrAI Mosaik Interface’s documentation! — palaestrAI Mosaik Interface documentation

# Welcome to palaestrAI Mosaik Interface’s documentation!

This module provides an ARL environment to couple mosaik simulations and ARL.

Contents:

- Installation
  - Linux
  - OS-X and Windows
- Getting Started
  - Prerequisites
  - Preparing your world
  - Description function
  - Instance function
  - Add your script to PYTHONPATH
  - Configure the experiment file
- Configuration
- Example: MIDAS
  - Run the example
  - Changing Sensors and Actuators
- palaestrai_mosaik
  - palaestrai_mosaik package

# Indices and tables

- Index

- Module Index

- Search Page